@@ -27,53 +27,58 @@ MONGO_BINARIES = (
 #dir is a special kind of value tag where a os.makedirs is done
 #file is a special kind fo vlaue tag where a os.makedirs on basebath is done
 MONGOD_OPTIONS = {
-    'config' : 'value',
-    'quiet' : 'flag',
-    'port' : 'value',
-    'logpath' : 'file',
-    'logappend' : 'flag',
-    'fork' : 'flag',
-    'bind_ip' : 'value',
-    'dbpath' : 'dir',
-    'directoryperdb' : 'flag',
-    'repairpath' : 'dir',
-    'cpu' : 'flag',
-    'noauth' : 'flag',
-    'auth' : 'flag',
-    'objcheck' : 'flag',
-    'quota' : 'flag',
-    'quotaFiles' : 'value',
     'appsrvpath' : 'dir',
+    'arbiter' : 'value',
+    'auth' : 'flag',
+    'autoresync' : 'flag',
+    'bind_ip' : 'value',
+    'config' : 'value',
+    'configsvr' : 'value',
+    'cpu' : 'flag',
+    'dbpath' : 'dir',
+    'diaglog' : 'value',
+    'directoryperdb' : 'flag',
+    'fastsync' : 'flag',
+    'fork' : 'flag',
+    'ipv6' : 'flag',
+    'logappend' : 'flag',
+    'logpath' : 'file',
+    'master' : 'flag',
+    'maxConns' : 'value',
+    'noMoveParanoia' : 'flag',
+    'noauth' : 'flag',
     'nocursors' : 'flag',
     'nohints' : 'flag',
     'nohttpinterface' : 'flag',
-    'rest' : 'flag',
-    'noscripting' : 'flag',
     'noprealloc' : 'flag',
-    'smallfiles' : 'flag',
+    'noscripting' : 'flag',
+    'notablescan' : 'flag',
+    'nounixsocket' : 'flag',
     'nssize' : 'value',
-    'diaglog' : 'value',
+    'objcheck' : 'flag',
+    'only' : 'value',
+    'opIdMem' : 'value',
+    'oplogSize' : 'value',
+    'pairwith' : 'value',
+    'pidfilepath' : 'value',
+    'port' : 'value',
+    'profile' : 'value',
+    'quiet' : 'flag',
+    'quota' : 'flag',
+    'quotaFiles' : 'value',
+    'repair' : 'flag',
+    'repairpath' : 'dir',
+    'replSet' : 'value',
+    'rest' : 'flag',
+    'shardsvr' : 'value',
+    'slave' : 'flag',
+    'slavedelay' : 'value',
+    'slowms' : 'value',
+    'smallfiles' : 'flag',
+    'source' : 'value',
+    'syncdelay' : 'value',
     'sysinfo' : 'flag',
     'upgrade' : 'flag',
-    'repair' : 'flag',
-    'notablescan' : 'flag',
-    'syncdelay' : 'value',
-    'profile' : 'value',
-    'slowms' : 'value',
-    'maxConns' : 'value',
-    'master' : 'flag',
-    'slave' : 'flag',
-    'source' : 'value',
-    'only' : 'value',
-    'pairwith' : 'value',
-    'arbiter' : 'value',
-    'slavedelay' : 'value',
-    'fastsync' : 'flag',
-    'autoresync' : 'flag',
-    'oplogSize' : 'value',
-    'opIdMem' : 'value',
-    'configsvr' : 'value',
-    'shardsvr' : 'value',
 }
 
 class Recipe(zc.recipe.egg.Eggs):
